pub struct Message {
pub role: String,
pub content: String,
}Fields
role: Stringcontent: StringImplementations
Sourceimpl Message
impl Message
pub fn new(role: impl Into<String>, content: impl Into<String>) -> Self
Sourcepub fn is_tool_call(&self) -> bool
pub fn is_tool_call(&self) -> bool
Check if this message contains a tool_use content block This is a lightweight check that looks for the “type”:“tool_use” pattern in content
Sourcepub fn is_tool_result(&self) -> bool
pub fn is_tool_result(&self) -> bool
Check if this message contains a tool_result content block This is a lightweight check that looks for the “type”:“tool_result” pattern in content